summaryrefslogtreecommitdiff
path: root/Build
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2020-03-03 22:40:15 +0000
committerKarl Berry <karl@freefriends.org>2020-03-03 22:40:15 +0000
commitf76a89d7f9fc8837ce20a63e3a29b2ba75823159 (patch)
tree2abe88ee59b0fbfefccfc3c727f995e856b0eba9 /Build
parentf6bb2b5974c9dc15a4530842100d30fe1981b973 (diff)
lualatex use luahbtex
git-svn-id: svn://tug.org/texlive/trunk@54035 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build')
-rwxr-xr-xBuild/source/texk/texlive/linked_scripts/texlive/tlmgr.pl22
-rw-r--r--Build/source/texk/texlive/tl_support/fmtutil.cnf5
2 files changed, 15 insertions, 12 deletions
diff --git a/Build/source/texk/texlive/tl_support/fmtutil.cnf b/Build/source/texk/texlive/tl_support/fmtutil.cnf
index e2cfa1cd17f..b6a50b56f88 100644
--- a/Build/source/texk/texlive/tl_support/fmtutil.cnf
+++ b/Build/source/texk/texlive/tl_support/fmtutil.cnf
@@ -1,4 +1,4 @@
-# Generated by /home/texlive/karl/Master/bin/x86_64-linux/tlmgr on Sun Feb 16 19:07:44 2020
+# Generated by /home/texlive/karl/Master/bin/x86_64-linux/tlmgr on Mon Mar 2 23:04:51 2020
# Originally written by Thomas Esser, 1998. Public domain.
#
# For guidance on how to support local formats, see the man
@@ -77,7 +77,7 @@ pdfjadetex pdftex language.dat *pdfjadetex.ini
latex pdftex language.dat -translate-file=cp227.tcx *latex.ini
pdflatex pdftex language.dat -translate-file=cp227.tcx *pdflatex.ini
dvilualatex luatex language.dat,language.dat.lua dvilualatex.ini
-lualatex luatex language.dat,language.dat.lua lualatex.ini
+lualatex luahbtex language.dat,language.dat.lua lualatex.ini
#
# from latex-bin-dev:
latex-dev pdftex language.dat -translate-file=cp227.tcx *latex.ini
@@ -93,6 +93,7 @@ luahbtex luahbtex language.def,language.dat.lua luatex.ini
#
# from luajittex:
luajittex luajittex language.def,language.dat.lua luatex.ini
+luajithbtex luajithbtex language.def,language.dat.lua luatex.ini
#
# from luatex:
luatex luatex language.def,language.dat.lua luatex.ini
diff --git a/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl b/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
index c08ad2c3339..418f2218788 100755
--- a/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
+++ b/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
@@ -1,12 +1,12 @@
#!/usr/bin/env perl
-# $Id: tlmgr.pl 53842 2020-02-19 07:28:40Z preining $
+# $Id: tlmgr.pl 54001 2020-03-02 17:58:52Z karl $
#
# Copyright 2008-2020 Norbert Preining
# This file is licensed under the GNU General Public License version 2
# or any later version.
-my $svnrev = '$Revision: 53842 $';
-my $datrev = '$Date: 2020-02-19 08:28:40 +0100 (Wed, 19 Feb 2020) $';
+my $svnrev = '$Revision: 54001 $';
+my $datrev = '$Date: 2020-03-02 18:58:52 +0100 (Mon, 02 Mar 2020) $';
my $tlmgrrevision;
my $tlmgrversion;
my $prg;
@@ -5714,7 +5714,7 @@ sub check_executes {
next if ($name eq "cont-en"); # too confusing
# we check that the name exist in bin/$arch
if (",$TeXLive::TLConfig::PartialEngineSupport," =~ /,$engine,/) {
# luajittex is special since it is not available on all architectures
# due to inherent reasons (machine code);
# luahbtex is special until we build it everywhere for TL'20.
#
@@ -5726,7 +5726,7 @@ sub check_executes {
# * if tlpkg/tlpsrc/<engine>.tlpsrc is *not* available (i.e., not
# the development tree) we just ignore it completely.
my $pkg;
- if ($engine eq "luajittex") {
+ if ($engine =~ /luajit(hb)?tex/) {
$pkg = "luajittex";
} elsif ($engine eq "luahbtex") {
$pkg = "luahbtex";
@@ -7144,11 +7144,13 @@ and the repository are not compatible:
# check for being frozen
if ($remotetlpdb->config_frozen) {
my $frozen_msg = <<FROZEN;
-TeX Live $TeXLive::TLConfig::ReleaseYear is frozen forever and will no
-longer be updated. This happens in preparation for a new release.
+TeX Live $TeXLive::TLConfig::ReleaseYear is frozen and will no longer
+be routinely updated. This happens in preparation for a new release.
+
+If you're willing to help with pretesting the new release, and we hope
+you are, (when pretests are available), please read
+https://tug.org/texlive/pretest.html.
-If you're interested in helping to pretest the new release (when
-pretests are available), please read https://tug.org/texlive/pretest.html.
Otherwise, just wait, and the new release will be ready in due time.
FROZEN
# don't die here, we want to allow updates even if tlnet is frozen!
@@ -9999,7 +10001,7 @@ This script and its documentation were written for the TeX Live
distribution (L<https://tug.org/texlive>) and both are licensed under the
GNU General Public License Version 2 or later.
-$Id: tlmgr.pl 53842 2020-02-19 07:28:40Z preining $
+$Id: tlmgr.pl 54001 2020-03-02 17:58:52Z karl $
=cut
# test HTML version: pod2html --cachedir=/tmp tlmgr.pl >/tmp/tlmgr.html
@@ -5714,7 +5714,7 @@ sub check_executes {
# we check that the name exist in bin/$arch
if (",$TeXLive::TLConfig::PartialEngineSupport," =~ /,$engine,/) {
- # luajittex is special since it is not available on all architectures
+ # luajit[hb]tex is special since it is not available on all architectures
# due to inherent reasons (machine code);
# luahbtex is special until we build it everywhere for TL'20.